"""
instance: Type-safe spatial primitives for YOLO detection pipelines.

Provides validated geometric containers (Point, Box, Polygon, Obb, YOLOInstance)
with normalized coordinate support and immutable transformations.
"""

from acmenra_cv.instance.point import Point
from acmenra_cv.instance.box import Box
from acmenra_cv.instance.obb import Obb
from acmenra_cv.instance.polygon import Polygon
from acmenra_cv.instance.instance import Instance

__all__ = [
    'Point',
    'Box',
    'Polygon',
    'Obb',
    'Instance',
]

__version__ = "0.1.6.5"